pub struct CloneArgs { /* private fields */ }Implementations
Sourceimpl CloneArgs
impl CloneArgs
pub const fn new(flags: CloneFlags) -> Self
Sourcepub fn set_child_tid(&mut self, child_tid_ptr: *mut TidT) -> &mut Self
pub fn set_child_tid(&mut self, child_tid_ptr: *mut TidT) -> &mut Self
Where to store the child Tid in the child’s memory, this should be passed to the child
Sourcepub fn set_parent_tid(&mut self, parent_tid: *mut TidT) -> &mut Self
pub fn set_parent_tid(&mut self, parent_tid: *mut TidT) -> &mut Self
Where to store the child Tid in the parent’s memory, this should be passed to the parent
Sourcepub fn set_stack(&mut self, stack: *mut u8) -> &mut Self
pub fn set_stack(&mut self, stack: *mut u8) -> &mut Self
Set the allocated thread stack area, take care of how that memory is handled
pub fn set_tls(&mut self, tls: usize) -> &mut Self
Sourcepub fn set_exit(&mut self, exit_signal: SignalKind) -> &mut Self
pub fn set_exit(&mut self, exit_signal: SignalKind) -> &mut Self
Low byte is the exit signal on a clone call