pub fn bulk_transfer(
fd: Fd,
endpoint: u32,
data: &mut [u8],
timeout: u32,
) -> Result<usize>Expand description
Make a bulk transfer on the hid fd specified by fd at endpoint, data is either an
input or output buffer, timeout is specified in milliseconds.
Errors
Various ioctl errors, like a bad fd, bad endpoint, buffer too small etc.